@@ -149,24 +149,24 @@ class SlappResponseObject:
         Ranking (number), bracket name, tournament name
         """
         result = []
-        if p.guid.__str__() in self.placements_for_players:
-            low_ink_sources = list(filter(lambda s: "low-ink-" in s, self.placements_for_players[p.guid.__str__()]))
-            for source_id in low_ink_sources:
-                source_name = self.sources[source_id]
+        low_ink_sources = [s for s in self.placements_for_players.get(p.guid.__str__(), []) if "low-ink-" in s]
+        for source_id in low_ink_sources:
+            source_name = self.sources[source_id]
 
-                # Take only the brackets useful to us
-                # i.e. Alpha, Beta, Gamma, and previous Top Cuts.
-                # Plus the bracket must have had placements in it (a winning team)
-                brackets = list(filter(lambda b:
-                                       (b.name.startswith("Alpha") or
-                                        b.name.startswith("Beta") or
-                                        b.name.startswith("Gamma") or
-                                        b.name.startswith("Top Cut")) and
-                                       1 in bracket.placements.players_by_placement, self.placements_for_players[p.guid.__str__()][source_id]))
-                for bracket in brackets:
-                    for placement in bracket.placements.players_by_placement:
-                        if p.guid.__str__() in placement:
-                            result.append((placement, bracket.name, source_name))
+            # Take only the brackets useful to us
+            # i.e. Alpha, Beta, Gamma, and previous Top Cuts.
+            # Plus the bracket must have had placements in it (a winning team)
+            brackets = [b for b in self.placements_for_players[p.guid.__str__()][source_id] if
+                        (
+                                b.name.startswith("Alpha") or
+                                b.name.startswith("Beta") or
+                                b.name.startswith("Gamma") or
+                                b.name.startswith("Top Cut")
+                        ) and 1 in b.placements.players_by_placement]
+            for bracket in brackets:
+                for placement in bracket.placements.players_by_placement:
+                    if p.guid in bracket.placements.players_by_placement[placement]:
+                        result.append((placement, bracket.name, source_name))
         return result
 
     def best_low_ink_placement(self, p: Player) -> Optional[Tuple[int, str, str]]:
